llqres - Query a reservation

Use the llqres command to return information about reservations in
LoadLeveler.


Syntax
 

llqres   { -? | -H | -v | -W | [-l | -r] [-s] [[-u user_list] [-g
         group_list]
         [-h host_list | -h all] [ -M midplane_list | -M all] [-b
         begin_time]
         [-e end_time] | -R reservation_list] }


Flags


-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-W 
   Specifies that the width of columns in tabular output will be
   increased to fit the widest entry.

-l 
   Specifies that a long listing be generated for each reservation to be
   queried.

-r 
   Specifies raw mode for output. Each reservation will occupy one line
   with the output fields separated by an exclamation point (!). The
   order of the output fields is: 

   ID       The ID assigned to the reservation by LoadLeveler.

   Type     The type of reservation. For a one-time reservation, the
            type will be One-time and for a recurring reservation, it
            will be Recurring. For a flexible reservation, it will be
            Flexible.

   Creation Time
            The creation time of the reservation.

   Owner    The reservation owner.

   Group    A LoadLeveler group that will own the reservation.

   Start Time
            Specifies the start time for a reservation.

   Duration The reservation duration displayed in minutes.

   Expected End Time
            Specifies the expected end time of the reservation.

   Flexible Job Id
            For a flexible reservation, this is a string containing the
            job ID of the flexible job.

   SHARED   Specifies the SHARED value for the reservation.

   REMOVE_ON_IDLE
            Specifies the REMOVE_ON_IDLE value for the reservation.

   Binding Method
            Specifies the BINDING method value used when jobs steps are
            bound to the reservation.

   Status   The status of the reservation.

   Modified By
            The user who modified the reservation.

   Modification Time
            The time the reservations was modified.

   Number of Users
            The number of users.

   Users    The names of the users.

   Number of Groups
            The number of groups.

   Groups   The names of the groups.

   Notification Pgm
            The name of the notification program.

   Notification Args
            Lists the user-supplied arguments for the notification
            program.

   Number of Nodes
            The number of reserved nodes.

   List of Nodes
            The list of nodes.

   Floating Resource
            A list of floating consumable resources that were requested
            by the reservation.

   Number of bound steps
            The number of bound steps.

   Bound Job Steps
            The name of the bound job steps.

-s 
   Specifies that short host names will be used in the output of machine
   names.

-u user_list
   Specifies a blank-delimited list of users. Reservations to be queried
   are owned by one of these users.

-g group_list
   Specifies a blank-delimited list of LoadLeveler groups. Reservations
   to be queried are owned by one of these groups.

-h all

-h host_list
   Specifies a blank-delimited list of machines or all machines.
   Reservations to be queried use one or more of these machines.

-M all

 -M midplane_list
   Specifies all or a blank-delimited list of midplanes in the Blue Gene
   system. Reservations to be queried use one or more of these
   midplanes.

-b begin_time
   Reservations to be queried are active at or after the specified begin
   time. The -b flag can be used together with the -e flag to query
   reservations expected to be active between the begin and end times.
   The begin_time must be specified using the format [mm/dd[/[cc]yy]]
   HH:MM. Hours must be specified using a 24-hour clock.

-e end_time
   Reservations to be queried are active at or before the specified end
   time. The -e flag can be used together with the -b flag to query
   reservations expected to be active between the begin and end times.
   The end_time must be specified using the format [mm/dd[/[cc]yy]]
   HH:MM. Hours must be specified using a 24-hour clock.

-R reservation_list
   Is a blank-delimited list of reservation identifiers to be queried.
   The format of a full LoadLeveler reservation identifier is
   [host.]rid[.r]. 

   where:
    
   *  host is the name of the machine that assigned the reservation
      identifier.
   *  rid is the number assigned to the reservation when it was created.
      An rid is required.
   *  r indicates that this is a reservation ID (r is optional).    

   The reservation identifier can be specified in an abbreviated form,
   rid[.r], when the command is invoked on the same machine that
   assigned the reservation identifier. In this case, LoadLeveler will
   use the local machine's host name to construct the full reservation
   identifier.    

   When -R is specified, -u, -g, and -h are ignored.


Description


All users can issue this command. Reservations satisfying all criteria
specified by -u, -g, -h or -M, -b, and -e will be queried if more than
one of these options are present. The -h and -M flags are mutually
exclusive. No reservation information will be returned if both are
specified at the same time. By default, the llqres command queries all
existing reservations.

This command is for the BACKFILL scheduler only.


Examples


When the BG_ENABLED keyword is set to false in the configuration file,
the following examples apply.

1. When issuing the llqres command, you should receive output similar to
   the following: 

   ID 		                  	 Owner      ST Start Time  Duration #Nodes 
   ------------------------ ---------- -- ----------- --------  ------ 
   c197blade4b01.55.r       loadl      W  3/4 07:10       2     1
   c197blade4b01.53.r       loadl      W  --/-- --:--   120     -
   c197blade4b01.52.r       loadl      W  3/3 13:30      30     1
    

   Notes: 

   a. In this example, c197blade4b01.52.r is a one-time reservation,
      c197blade4b01.53.r is a flexible reservation, and
      c197blade4b01.55.r is a recurring reservation. A flexible
      reservation will not display a start time while it is in the 'W'
      or Waiting state.

   b. If the flexible reservation is not in Active state, the start time
      will be in the form "--/-- --:--". The number of nodes will be set
      to "-".

2. When issuing the llqres -l command, you should receive output similar
   to the following for a one-time reservation: 

   =============== Reservation c197blade4b01.ppd.pok.ibm.com.52.r ===============
   ID: c197blade4b01.ppd.pok.ibm.com.52.r
                     Type: ONE_TIME
            Creation Time: Thu 03 Mar 2011 01:21:45 PM EST
                    Owner: loadl
                    Group: No_Group
               Start Time: Thu 03 Mar 2011 01:30:00 PM EST
                 Duration: 30 minutes
        Expected End Time: Thu 03 Mar 2011 02:00:00 PM EST
          Flexible Job Id:
                   SHARED: no
           REMOVE_ON_IDLE: no
           Binding Method: firm
                   Status: WAITING
              Modified By: loadl
        Modification Time: Thu 03 Mar 2011 01:21:45 PM EST
                    Users: 0
                   Groups: 0
         Notification Pgm:
        Notification Args:
                    Nodes: 1
   c197blade4b01.ppd.pok.ibm.com
        Floating Resource: Things(8/8/8)
                Job Steps: 0

3. When issuing the llqres -l command, you should receive output similar
   to the following for a recurring reservation:

   =============== Reservation c197blade4b01.ppd.pok.ibm.com.55.r.0 ===============
   ID: c197blade4b01.ppd.pok.ibm.com.55.r.0
                    Type: RECURRING
           Creation Time: Thu 03 Mar 2011 01:23:21 PM EST
                   Owner: loadl
                   Group: No_Group
              Start Time: Fri 04 Mar 2011 07:10:00 AM EST
                Duration: 2 minutes
       Expected End Time: Fri 04 Mar 2011 07:12:00 AM EST
         Flexible Job Id:
                  SHARED: no
          REMOVE_ON_IDLE: no
          Binding Method: firm
                  Status: WAITING
             Modified By: loadl
       Modification Time: Thu 03 Mar 2011 01:23:21 PM EST
                   Users: 0
                  Groups: 0
        Notification Pgm:
       Notification Args:
                   Nodes: 1
   c197blade4b01.ppd.pok.ibm.com
       Floating Resource:
               Job Steps: 0
   --------------------------- Future Occurrences ---------------------------
              Expiration: Sun 06 Mar 2011 07:10:00 AM EST
              Recurrence: 10 7 * * *
                          07:10 AM of
                          every day
              Start Time: (0) (Fri 04 Mar 2011 07:10:00 AM EST)
                          (1) (Sat 05 Mar 2011 07:10:00 AM EST)
                          (2) (Sun 06 Mar 2011 07:10:00 AM EST)
           Canceled OIDs: (none)
                Duration: 2 minutes
                  SHARED: no
          REMOVE_ON_IDLE: no
                   Users: 0
                  Groups: 0

4. When issuing the llqres -l command for a flexible reservation in
   WAITING state created using the -f option, you should receive output
   similar to the following: 

   =============== Reservation c890f2ec01.ppd.pok.ibm.com.17.r =============== 
   ID:                c890f2ec01.ppd.pok.ibm.com.17.r 
   Type:              FLEXIBLE 
   Creation Time:     Wed 27 Oct 2010 11:22:00 AM EDT 
   Owner:             llbld 
   Group:             No_Group 
   Start Time:        --/-- --:-- 
   Duration:          10 minutes 
   Expected End Time: --/-- --:-- 
   Flexible Job Id:   c890f2ec01.ppd.pok.ibm.com.22.0 
   SHARED:            no 
   REMOVE_ON_IDLE:    no 
   Binding Method:    firm 
   Status:            WAITING 
   Modified By:       llbld 
   Modification Time: Wed 27 Oct 2010 11:22:00 AM EDT 
   Users:             0 
   Groups:            0 
   Notification Pgm: 
   Notification Args: 
   Nodes: 
   Floating Resource: MyArea(15/15/15) 
   Job Steps:         0 
   -------------------- Flexible Reservation Information -------------------- 
   Selection Method:  RESERVATION_BY_JCF 
   Expiration:        Mon 25 Apr 2011 11:22:00 AM EDT 
   JCF:               verylongjob.cmd 
   Host List: 
   =============== Reservation c890f2ec01.ppd.pok.ibm.com.16.r =============== 
   ID:                c890f2ec01.ppd.pok.ibm.com.16.r 
   Type:              FLEXIBLE 
   Creation Time:     Wed 27 Oct 2010 11:21:16 AM EDT 
   Owner:             llbld 
   Group:             No_Group 
   Start Time:        Wed 27 Oct 2010 11:21:16 AM EDT 
   Duration:          15 minutes 
   Expected End Time: Wed 27 Oct 2010 11:36:16 AM EDT 
   Flexible Job Id:   c890f2ec01.ppd.pok.ibm.com.21.0 
   SHARED:            no 
   REMOVE_ON_IDLE:    no 
   Binding Method:    firm 
   Status:            ACTIVE 
   Modified By:       llbld 
   Modification Time: Wed 27 Oct 2010 11:21:16 AM EDT 
   Users:             0 
   Groups:            0 
   Notification Pgm: 
   Notification Args: 
   Nodes:             1 
   c890f2ec01.ppd.pok.ibm.com 
   Floating Resource: MyArea(19/19/19) 
   Job Steps:         0 
   

   Notes: 

   a. For a flexible reservation in WAITING state, the start time, end
      time, and node allocation are not set until the reservation
      becomes active.

   b. If the reservation requested floating resources, the Floating
      Resource field will display the values in the format
      "(available/initial/requested)", where: 

      available 
               Is the amount of resources currently available in the
               reservation.

      initial  Is the amount of resources the reservation are able to
               obtain.

      requested 
               Is the amount of resources you requested the reservation
               to obtain.
   c. For a flexible reservation in WAITING state, a section "Flexible
      Reservation Information is displayed containing the node selection
      method, expiration time, and node values.

5. When issuing the llqres -l command for a flexible reservation in
   WAITING state created using the -n option, you should receive output
   similar to the following: 

   =============== Reservation c197e325n01.ppd.pok.ibm.com.72.r ===============
                  ID: c197e325n01.ppd.pok.ibm.com.72.r
                Type: FLEXIBLE
       Creation Time: Mon 17 May 2010 08:39:13 AM EDT
               Owner: llbld
               Group: No_Group
          Start Time: --/-- --:--
            Duration: 2 minutes
   Expected End Time: --/-- --:--
     Flexible Job Id: c197e325n01.ppd.pok.ibm.com.113.0
              SHARED: no
      REMOVE_ON_IDLE: no
      Binding Method: firm
              Status: WAITING
         Modified By: llbld
   Modification Time: Mon 17 May 2010 08:39:13 AM EDT
               Users: 0
              Groups: 0
    Notification Pgm: 
   Notification Args: 
               Nodes: 
   Floating Resource: 
           Job Steps: 0
   -------------------- Flexible Reservation Information --------------------
    Selection Method: RESERVATION_BY_NODE
          Expiration: Tue 18 May 2010 08:39:13 AM EDT
           Num Nodes: 3

6. When issuing the llqres -l command for a flexible reservation in
   WAITING state created using the -F option, you should receive output
   similar to the following: 

   =============== Reservation c197e325n01.ppd.pok.ibm.com.74.r ===============
                  ID: c197e325n01.ppd.pok.ibm.com.74.r
                Type: FLEXIBLE
       Creation Time: Mon 17 May 2010 08:42:37 AM EDT
               Owner: llbld
               Group: No_Group
          Start Time: --/-- --:--
            Duration: 2 minutes
   Expected End Time: --/-- --:--
     Flexible Job Id: c197e325n01.ppd.pok.ibm.com.115.0
              SHARED: no
      REMOVE_ON_IDLE: no
      Binding Method: firm
              Status: WAITING
         Modified By: llbld
   Modification Time: Mon 17 May 2010 08:42:37 AM EDT
               Users: 0
              Groups: 0
    Notification Pgm: 
   Notification Args: 
               Nodes: 
   Floating Resource: 
           Job Steps: 0
   -------------------- Flexible Reservation Information --------------------
    Selection Method: RESERVATION_BY_HOSTLIST

7. When issuing the llqres -l command for a flexible reservation in
   WAITING state using the RESERVATION_BY_HOSTFILE selection method, you
   should receive output similar to the following: 

   =============== Reservation c197e325n01.ppd.pok.ibm.com.75.r ===============
                  ID: c197e325n01.ppd.pok.ibm.com.75.r
                Type: FLEXIBLE
       Creation Time: Mon 17 May 2010 08:43:05 AM EDT
               Owner: llbld
               Group: No_Group
          Start Time: --/-- --:--
            Duration: 2 minutes
   Expected End Time: --/-- --:--
     Flexible Job Id: c197e325n01.ppd.pok.ibm.com.116.0
              SHARED: no
      REMOVE_ON_IDLE: no
      Binding Method: firm
              Status: WAITING
         Modified By: llbld
   Modification Time: Mon 17 May 2010 08:43:05 AM EDT
               Users: 0
              Groups: 0
    Notification Pgm: 
   Notification Args: 
               Nodes: 
   Floating Resource: 
           Job Steps: 0
   -------------------- Flexible Reservation Information --------------------
    Selection Method: RESERVATION_BY_HOSTFILE
          Expiration: Tue 18 May 2010 08:43:05 AM EDT
           Host List:  c197e325n01.ppd.pok.ibm.com c197e325n02.ppd.pok.ibm.com \
                       c197e325n03.ppd.pok.ibm.com c197e325n04.ppd.pok.ibm.com \
                       c197e325n05.ppd.pok.ibm.com c197e325n06.ppd.pok.ibm.com \
                       c197e325n07.ppd.pok.ibm.com c197e325n08.ppd.pok.ibm.com

8. When issuing the llqres -l command for a flexible reservation in
   ACTIVE state you should receive output similar to the following: 

   =============== Reservation c197e325n01.ppd.pok.ibm.com.76.r ===============
                  ID: c197e325n01.ppd.pok.ibm.com.76.r
                Type: FLEXIBLE
       Creation Time: Mon 17 May 2010 08:45:49 AM EDT
               Owner: llbld
               Group: No_Group
          Start Time: Mon 17 May 2010 08:45:49 AM EDT
            Duration: 2 minutes
   Expected End Time: Mon 17 May 2010 08:47:49 AM EDT
     Flexible Job Id: c197e325n01.ppd.pok.ibm.com.117.0
              SHARED: no
      REMOVE_ON_IDLE: no
      Binding Method: firm
              Status: ACTIVE
         Modified By: llbld
   Modification Time: Mon 17 May 2010 08:45:49 AM EDT
               Users: 0
              Groups: 0
    Notification Pgm: 
   Notification Args: 
               Nodes: 1
                      c197e325n01.ppd.pok.ibm.com
   Floating Resource: 
           Job Steps: 0

9. To determine if any reservations will be active on the machine c94n01
   before performing an hours worth of maintenance beginning at 8:00 on
   02/18/2009, issue the following command: 

   llqres -b 02/18/2009 8:00 -e 02/18/2009 9:00 -h c94n01

   You should receive output similar to the following: 

   Id              Owner     ST  Start Time   Duration #Nodes
   -----------     -----     --  -----------  -------- ------
   c94n16.31.r     dave      W   02/18  02:00    420      4

10. There are no job steps associated with a reservation in the
   following example. The short form is used for host names: 

   llqres -r -s -R c94n16.30.r    

   You should receive output similar to the following: 

   c94n16.30.r!ONE_TIME!Mon Feb 16 08:12:23 EST 2009!loadl!No_Group! 
      Mon Feb 16 14:00:00 EST 2009!120!Mon Feb 16 16:00:00 EST 
   2009!!no!no!firm!ACTIVE!loadl! Mon Feb 16 10:21:14 EST  
   2009!0!!1!loadlusr!!!3!c94n01,c94n11,c94n12!!0!

11. There are job steps associated with a reservation in the following
   example. The short form is used for host names: 

   llqres -r -s -R c94n16.31.r

    You should receive output similar to the following: 

   c94n16.31.r!ONE_TIME!Mon Feb 16 10:35:18 EST 2009!dave!No_Group! 
      Mon Feb 16 02:00:00 EST 2009!420!Mon Feb 16 09:00:00 EST 
   2009!!no!yes!firm!WAITING!dave! Mon Feb 16 10:55:18 
   EST 2009!0!!0!!!!4!c94n01,c94n02,c94n12,c94n16!!1!c94n16.25.0

12. To show all reservation occurrences from March 15th 00:01 until the
   reservation expires, issue the following command. Note that the first
   occurrence in this interval is occurrence 4. Of the six job steps
   bound to the reservation, only two of them are bound to occurrence 4
   and are shown in the first section of the listing. All six are shown
   in the second part of the listing. Occurrence 7 has been canceled. It
   is listed as a canceled occurrence under the "Canceled OIDs:" heading
   and is omitted from the list of start times. 

   llqres -l -b 03/15 00:01 -R c94n16.64

   You should receive output similar to the following: 

   =============== Reservation c94n16.ppd.pok.ibm.com.64.r ===============
   ID: c94n16.ppd.pok.ibm.com.64.r.4
       Creation Time: Mon 23 Feb 10:55:18 AM EST 2009
               Owner: nathan
               Group: No_Group
          Start Time: Fri 13 Mar 07:00:00 PM EDT 2009
            Duration: 120 minutes
   Expected End Time: Fri 13 Mar 09:00:00 PM EDT 2009
              SHARED: no
      REMOVE_ON_IDLE: no
      Binding Method: firm
              Status: WAITING
         Modified By: nathan
   Modification Time: Mon 23 Feb 10:55:18 AM EST 2009
               Users: 0
              Groups: 0
               Nodes: 4
                      c94n01.ppd.pok.ibm.com
                      c94n02.ppd.pok.ibm.com
                      c94n12.ppd.pok.ibm.com
                      c94n16.ppd.pok.ibm.com
           Job Steps: 2
                      c94n15.ppd.pok.ibm.com.28.0
                      c94n16.ppd.pok.ibm.com.29.0
   ------------------------- Future Occurrences -------------------------
          Expiration: Mon 30 Mar 11:59:00 PM EDT 2009
          Recurrence: 0 19 * * 5-6
                      07:00 PM
                      Friday, Saturday of each week
                      Every month
         Start Times: (5) Sat 14 Mar 07:00:00 PM EDT 2009
                      (6) Fri 20 Mar 07:00:00 PM EDT 2009
                      (8) Fri 27 Mar 07:00:00 PM EDT 2009
                      (9) Sat 28 Mar 07:00:00 PM EDT 2009
        Canceled OIDs: 7
             Duration: 120 minutes
               SHARED: no
       REMOVE_ON_IDLE: no
                Users: 0
               Groups: 0
            Job Steps: 6
                       c94n15.ppd.pok.ibm.com.28.0 (4)
                       c94n16.ppd.pok.ibm.com.29.0 (4)
                       c94n16.ppd.pok.ibm.com.30.0 (5)
                       c94n16.ppd.pok.ibm.com.30.1 (5)
                       c94n16.ppd.pok.ibm.com.30.2 (5)
                       c94n16.ppd.pok.ibm.com.32.0 (8)

There are floating resources associated with an active flexible
reservation in the following example: 

llqres -r -R c197blade4b01.51.r 

You should receive output similar to the following: 

c197blade4b01.ppd.pok.ibm.com.51.r!FLEXIBLE!Tue 22 Feb 2011 01:51:13 PM EST!
loadl!No_Group!Tue 22 Feb 2011 01:51:13 PM EST!2!Tue 22 Feb 2011 01:53:13 PM EST!
c197blade4b01.ppd.pok.ibm.com.124.0!no!no!firm!ACTIVE!loadl!
Tue 22 Feb 2011 01:51:13 PM EST!0!!0!!!!1!c197blade4b01.ppd.pok.ibm.com!Things(2/2/2)!0!

In a Blue Gene environment, when the BG_ENABLED keyword is set to true
in the configuration file, the following examples apply. 

1. When issuing the llqres command, you should receive output similar to
   the following: 

   ID                       Owner      ST Start Time  Duration #Nodes #BG C-nodes
   ------------------------ ---------- -- ----------- -------- ------ -----------
   bgqfen5.9.r              vhu        W   1/1  00:00       60      1           0
   bgqfen5.7.r              vhu        W   1/30 22:10       60      0         256
   bgqfen5.6.r              vhu        W   1/10 10:00       10      0         512

2. The following example returns reservation information about all
   machines: 

   llqres -h all    

   You should receive output similar to the following: 

   ID                       Owner      ST Start Time  Duration #Nodes #BG C-nodes
   ------------------------ ---------- -- ----------- -------- ------ -----------
   bgqfen5.9.r              vhu        W   1/1  00:00       60      1           0

3. The following example generates a list of midplanes for R01-M0: 

   llqres -M R01-M0     

   You should receive output similar to the following: 

   ID                       Owner      ST Start Time  Duration #Nodes #BG C-nodes
   ------------------------ ---------- -- ----------- -------- ------ -----------
   bgqfen5.7.r              vhu        W   1/30 22:10       60      0         256
   bgqfen5.6.r              vhu        W   1/10 10:00       10      0         512

4. The following example shows a long listing of all reservations in a
   system where Blue Gene support is enabled: 

   llqres -l -R bgqfen5.6.r    

   You should receive output similar to the following:    

   =============== Reservation bgqfen5.rchland.ibm.com.6.r ===============
                  ID: bgqfen5.rchland.ibm.com.6.r
                Type: ONE_TIME
       Creation Time: Fri 02 Dec 2011 12:46:41 PM CST
               Owner: vhu
               Group: No_Group
          Start Time: Tue 10 Jan 2012 10:00:00 AM CST
            Duration: 10 minutes
   Expected End Time: Tue 10 Jan 2012 10:10:00 AM CST
     Flexible Job Id: 
              SHARED: no
      REMOVE_ON_IDLE: no
      Binding Method: firm
              Status: WAITING
         Modified By: vhu
   Modification Time: Fri 02 Dec 2011 12:48:38 PM CST
               Users: 0
              Groups: 0
    Notification Pgm: 
   Notification Args: 
               Nodes: 0
   Floating Resource: 
           Job Steps: 0
          BG C-nodes: 512
     BG Connectivity: TORUS TORUS TORUS TORUS
            BG Shape: 1x1x1x1
        BG Midplanes: 1
                      R00-M0
            BG Block: 

5. The following example shows reserving resources during the time
   period from 06:00 to 12:00 on 01/10/2012:

   llqres -b 01/10/2012 06:00 -e 01/10/2012 12:00    

   You should receive output similar to the following: 

   ID                       Owner      ST Start Time  Duration #Nodes #BG C-nodes
   ------------------------ ---------- -- ----------- -------- ------ -----------
   bgqfen5.6.r              vhu        W   1/10 10:00       10      0         512

6. To query a recurring reservation with no expiration on a Blue Gene
   system, issue:

   llqres -l -R bgqfen5.11.r    

   You should receive a response similar to the following:    

   =============== Reservation bgqfen5.rchland.ibm.com.11.r.0 ===============
                  ID: bgqfen5.rchland.ibm.com.11.r.0
                Type: RECURRING
       Creation Time: Fri 02 Dec 2011 02:40:27 PM CST
               Owner: vhu
               Group: No_Group
          Start Time: Tue 10 Jan 2012 03:00:00 PM CST
            Duration: 30 minutes
   Expected End Time: Tue 10 Jan 2012 03:30:00 PM CST
     Flexible Job Id: 
              SHARED: no
      REMOVE_ON_IDLE: no
      Binding Method: firm
              Status: WAITING
         Modified By: vhu
   Modification Time: Fri 02 Dec 2011 02:40:27 PM CST
               Users: 0
              Groups: 0
    Notification Pgm: 
   Notification Args: 
               Nodes: 0
   Floating Resource: 
           Job Steps: 0
          BG C-nodes: 512
     BG Connectivity: TORUS TORUS TORUS TORUS
            BG Shape: 1x1x1x1
        BG Midplanes: 1
                      R00-M0
            BG Block: 
   --------------------------- Future Occurrences ---------------------------
          Expiration: Sun 08 Jul 2012 04:00:00 PM CDT
          Recurrence: 0 15 * * *
                      03:00 PM of
                      every day
          Start Time: (0) (Tue 10 Jan 2012 03:00:00 PM CST)
                      (1) (Wed 11 Jan 2012 03:00:00 PM CST)
                      (2) (Thu 12 Jan 2012 03:00:00 PM CST)
                      (3) (Fri 13 Jan 2012 03:00:00 PM CST)
                      (4) (Sat 14 Jan 2012 03:00:00 PM CST)
                      (5) (Sun 15 Jan 2012 03:00:00 PM CST)
                      (6) (Mon 16 Jan 2012 03:00:00 PM CST)
                      (7) (Tue 17 Jan 2012 03:00:00 PM CST)
                      (8) (Wed 18 Jan 2012 03:00:00 PM CST)
                      (9) (Thu 19 Jan 2012 03:00:00 PM CST)
                      (10) (Fri 20 Jan 2012 03:00:00 PM CST)
                      (11) (Sat 21 Jan 2012 03:00:00 PM CST)
                      (12) (Sun 22 Jan 2012 03:00:00 PM CST)
                      ...
                      ...
                      ...
                      (167) (Mon 25 Jun 2012 03:00:00 PM CDT)
                      (168) (Tue 26 Jun 2012 03:00:00 PM CDT)
                      (169) (Wed 27 Jun 2012 03:00:00 PM CDT)
                      (170) (Thu 28 Jun 2012 03:00:00 PM CDT)
                      (171) (Fri 29 Jun 2012 03:00:00 PM CDT)
                      (172) (Sat 30 Jun 2012 03:00:00 PM CDT)
                      (173) (Sun 01 Jul 2012 03:00:00 PM CDT)
                      (174) (Mon 02 Jul 2012 03:00:00 PM CDT)
                      (175) (Tue 03 Jul 2012 03:00:00 PM CDT)
                      (176) (Wed 04 Jul 2012 03:00:00 PM CDT)
                      (177) (Thu 05 Jul 2012 03:00:00 PM CDT)
                      (178) (Fri 06 Jul 2012 03:00:00 PM CDT)
                      (179) (Sat 07 Jul 2012 03:00:00 PM CDT)
                      (180) (Sun 08 Jul 2012 03:00:00 PM CDT)
       Canceled OIDs: (none)
            Duration: 30 minutes
              SHARED: no
      REMOVE_ON_IDLE: no
               Users: 0
              Groups: 0
           Job Steps: 0


Security


LoadLeveler administrators and users can issue this command.
