llrun - Run an interactive job

Use the llrun command to submit mpich or serial interactive jobs to
LoadLeveler to be dispatched based on job requirements specified with
the -k command option or in a job command file specified with the -f
command option.


Syntax


llrun {-? | -H | -v | [-q] [-l] [-w value] {-k  jcf_keyword_list [-s 
filename] | -f  filename} [-c command_string] } }


Flags


-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-q 
   Specifies quiet mode: print no messages other than error messages.

-l 
   Specifies that the interactive command or shell will be run locally.
   This option is ignored for serial jobs.

-w value
   Specifies how long to wait for resources to be allocated. 

   where value is one of the following:    

   IMMEDIATE
      Specifies to wait for LoadLeveler to complete one dispatch cycle.
      If resources cannot be allocated in one cycle, the llrun command
      will display an error message and exit. IMMEDIATE is case
      insensitive and is the default value.

   UNLIMITED 
      Specifies to wait indefinitely for resources to be allocated.
      UNLIMITED is case insensitive.

   integer > 0
      Is an integer value greater than 0 that specifies the number of
      seconds the llrun command will wait for resources to be allocated.
      If resources cannot be allocated in the specified time, llrun
      displays an error message and exits. 

      A value less than or equal to 0 is not permitted.

-s 
   Specifies the name of a file in which to save the generated job
   command file statements.

-f 
   Specifies a job command file that contains the job characteristics
   for the interactive job. The job command file specified may only 
   contain a single #@queue statement. A multiple step job command 
   file is not permitted.

-k jcf_keyword_list 
   Specifies a blank-delimited list of job characteristics specified as
   job command file keywords and values. 

   where each keyword value pair is specified as:

   keyword=value

   For more information about how to specify each keyword value, see the
   "Job command file keyword descriptions" topic in LoadLeveler: Using
   and Administering.    

   Note: If a job command file value contains blanks, the value must be
   surrounded by quotation marks. Furthermore, if a value contains
   quotation marks, the escape character must precede each quotation
   mark contained in the value. For example:
   requirements="(Machine == \"jupiter.ibm.com\")"

-c command_string
   Is a command string that is invoked either on the local machine or on
   the first machine in the list of machines allocated for the
   interactive job. If this option is not specified, either a local
   shell is started with LoadLeveler environment variables set or an
   interactive SSH session is started on the first machine. The -l
   option determines where the command or shell is started.


Description


The llrun command accepts a job command file with the -f option, or
creates a job command file using the keyword-value pairs specified using
the -k option. The job command file is submitted to LoadLeveler for
resource scheduling and allocation. Once resources have been allocated,
llrun uses SSH to start the specified command line on the first machine
in the list of machines allocated for the job. If a command string is
not specified, an interactive SSH session is started on the first
machine. If the -l option is specified, the command or shell is started
locally with LoadLeveler runtime environment variables set.

The -f option cannot be specified with the -k option.

The following constraints on submitting batch jobs also apply to
submitting interactive jobs with llrun: 

*  Users with uid or gid equal to 0 are not allowed to issue the llrun
   command.

*  Interactive jobs submitted by llrun are subject to the installation
   configured job filter. For information about writing a program to
   filter job scripts, see the "Filtering a job script" topic in
   LoadLeveler: Using and Administering.

*  The llrun command will display an error and fail to submit the job if
   the resources keyword does not match the resources to be enforced and
   LoadLeveler is set to check for the resources specification. For more
   information, see the "Defining usage policies for consumable
   resources" topic in LoadLeveler: Using and Administering.

Note: Conditions that would cause batch jobs to be rejected will cause
interactive jobs submitted with llrun to be canceled.

The following table lists the only job command file keywords that can be specified
in the llrun command. Keywords that are not listed are not supported.

Supported job command file keywords for the llrun command

+-----------------------+----------------------+----------------------+
| account_no            | as_limit             | blocking             |
+-----------------------+----------------------+----------------------+
| class                 | comment              | core_limit           |
+-----------------------+----------------------+----------------------+
| cpu_limit             | cpus_per_core        | data_limit           |
+-----------------------+----------------------+----------------------+
| env_copy              | environment          | file_limit           |
+-----------------------+----------------------+----------------------+
| group                 | host_file            | image_size           |
+-----------------------+----------------------+----------------------+
| island_count          | initialdir           | job_cpu_limit        |
+-----------------------+----------------------+----------------------+
| job_name              | job_type            | locks_limit          |
+-----------------------+----------------------+----------------------+
| mcm_affinity_options  | memlock_limit        | network              |
+-----------------------+----------------------+----------------------+
| node                  | node_resources       | node_topology        |
+-----------------------+----------------------+----------------------+
| node_usage            | nofile_limit         | notification         |
+-----------------------+----------------------+----------------------+
| notify_user           | nproc_limit          | parallel_threads     |
+-----------------------+----------------------+----------------------+
| preferences           | requirements         | resources            |
+-----------------------+----------------------+----------------------+
| rset                  | rss_limit            | stack_limit          |
+-----------------------+----------------------+----------------------+
| step_name             | step_resources       | task_affinity        |
+-----------------------+----------------------+----------------------+
| task_geometry         | tasks_per_node       | total_tasks          |
+-----------------------+----------------------+----------------------+
| totalmemory           | trace                | user_priority        |
+-----------------------+----------------------+----------------------+
| wall_clock_limit      |                      |                      |
+-----------------------+----------------------+----------------------+

Note: The following are not supported by the llrun command: 

*  job_type = bluegene or job_type = parallel
*  Checkpoint jobs
*  Reservations


Examples


1. To submit an interactive job to LoadLeveler based on the hydra.jcf
   job command file:

   #! /bin/ksh
   # @ job_type=MPICH
   # @ environment = COPY_ALL; 
   # @ class = No_Class
   # @ node = 3
   # @ total_tasks = 6
   # @ wall_clock_limit = 00:60:00
   # @ queue
  
   Create the hydra.cmd shell script with the following statements to
   invoke the mpiexec.hydra command to run an MPI program, mpi.a.out:

   #!/bin/ksh
   mpiexec.hydra -bootstrap ssh -bootstrap-exec llspawn.stdio -ppn 1 -f 
   $LOADL_HOSTFILE -n $LOADL_TOTAL_TASKS mpi.a.out

   Then issue:

   llrun -f hydra.jcf -c hydra.cmd

   You should receive a response similar to the following:

   (4 of 6): Calling MPI_Bcast: n = 0.
   (3 of 6): c111bc4n01.
   (3 of 6): Calling MPI_Bcast: n = 0.
   (0 of 6): c111bc4n01.
   (0 of 6): Calling MPI_Bcast: n = 100.
   (2 of 6): c111bc4n03.
   (2 of 6): Calling MPI_Bcast: n = 0.
   (5 of 6): c111bc4n03.
   (5 of 6): Calling MPI_Bcast: n = 0.
   (0 of 6): After MPI_Bcast call: n = 100.
   (3 of 6): After MPI_Bcast call: n = 100.
   (3 of 6): Consuming some cpu.
   (3 of 6): Spawning sleeping child.
   (0 of 6): Consuming some cpu.
   (0 of 6): Spawning sleeping child.
   (2 of 6): After MPI_Bcast call: n = 100.
   (2 of 6): Consuming some cpu.
   (2 of 6): Spawning sleeping child.
   (5 of 6): After MPI_Bcast call: n = 100.
   (5 of 6): Consuming some cpu.
   (5 of 6): Spawning sleeping child.
   (1 of 6): c111bc4n02.
   (1 of 6): Calling MPI_Bcast: n = 0.
   (1 of 6): After MPI_Bcast call: n = 100.
   (1 of 6): Consuming some cpu.
   (1 of 6): Spawning sleeping child.
   (4 of 6): After MPI_Bcast call: n = 100.
   (4 of 6): Consuming some cpu.
   (4 of 6): Spawning sleeping child.
   (3 of 6): Calling MPI_Bcast: m = 0.
   (1 of 6): Calling MPI_Bcast: m = 0.
   (4 of 6): Calling MPI_Bcast: m = 0.
   (0 of 6): Calling MPI_Bcast: m = 200.
   (1 of 6): After MPI_Bcast call: m = 200.
   (1 of 6): calling MPI_Finalize.
   (4 of 6): After MPI_Bcast call: m = 200.
   (4 of 6): calling MPI_Finalize.
   (0 of 6): After MPI_Bcast call: m = 200.
   (0 of 6): calling MPI_Finalize.
   (3 of 6): After MPI_Bcast call: m = 200.
   (3 of 6): calling MPI_Finalize.
   (2 of 6): Calling MPI_Bcast: m = 0.
   (2 of 6): After MPI_Bcast call: m = 200.
   (2 of 6): calling MPI_Finalize.
   (5 of 6): Calling MPI_Bcast: m = 0.
   (5 of 6): After MPI_Bcast call: m = 200.
   (5 of 6): calling MPI_Finalize.
   (0 of 6): Exiting.
   (3 of 6): Exiting.
   (2 of 6): Exiting.
   (5 of 6): Exiting.
   (1 of 6): Exiting.
   (4 of 6): Exiting.

2. To submit an interactive job to LoadLeveler based on the -k option,
   issue: 

   llrun -k job_type=MPICH environment=COPY_ALL class=No_Class node=3
   total_tasks=6 wall_clock_limit=00:60:00 -c hydra.cmd

   You should receive a response similar to the following:

   (5 of 6): c111bc4n03.
   (5 of 6): Calling MPI_Bcast: n = 0.
   (1 of 6): c111bc4n02.
   (1 of 6): Calling MPI_Bcast: n = 0.
   (4 of 6): c111bc4n02.
   (4 of 6): Calling MPI_Bcast: n = 0.
   (1 of 6): After MPI_Bcast call: n = 100.
   (1 of 6): Consuming some cpu.
   (1 of 6): Spawning sleeping child.
   (4 of 6): After MPI_Bcast call: n = 100.
   (4 of 6): Consuming some cpu.
   (4 of 6): Spawning sleeping child.
   (0 of 6): c111bc4n01.
   (0 of 6): Calling MPI_Bcast: n = 100.
   (0 of 6): After MPI_Bcast call: n = 100.
   (0 of 6): Consuming some cpu.
   (0 of 6): Spawning sleeping child.
   (3 of 6): c111bc4n01.
   (3 of 6): Calling MPI_Bcast: n = 0.
   (3 of 6): After MPI_Bcast call: n = 100.
   (3 of 6): Consuming some cpu.
   (3 of 6): Spawning sleeping child.
   (2 of 6): c111bc4n03.
   (2 of 6): Calling MPI_Bcast: n = 0.
   (2 of 6): After MPI_Bcast call: n = 100.
   (2 of 6): Consuming some cpu.
   (2 of 6): Spawning sleeping child.
   (5 of 6): After MPI_Bcast call: n = 100.
   (5 of 6): Consuming some cpu.
   (5 of 6): Spawning sleeping child.
   (4 of 6): Calling MPI_Bcast: m = 0.
   (1 of 6): Calling MPI_Bcast: m = 0.
   (3 of 6): Calling MPI_Bcast: m = 0.
   (0 of 6): Calling MPI_Bcast: m = 200.
   (1 of 6): After MPI_Bcast call: m = 200.
   (1 of 6): calling MPI_Finalize.
   (4 of 6): After MPI_Bcast call: m = 200.
   (4 of 6): calling MPI_Finalize.
   (0 of 6): After MPI_Bcast call: m = 200.
   (0 of 6): calling MPI_Finalize.
   (3 of 6): After MPI_Bcast call: m = 200.
   (3 of 6): calling MPI_Finalize.
   (5 of 6): Calling MPI_Bcast: m = 0.
   (2 of 6): Calling MPI_Bcast: m = 0.
   (2 of 6): After MPI_Bcast call: m = 200.
   (2 of 6): calling MPI_Finalize.
   (5 of 6): After MPI_Bcast call: m = 200.
   (5 of 6): calling MPI_Finalize.
   (0 of 6): Exiting.
   (3 of 6): Exiting.
   (1 of 6): Exiting.
   (2 of 6): Exiting.
   (5 of 6): Exiting.
   (4 of 6): Exiting.


Security


LoadLeveler administrators and users can issue this command.