llsubmit - Submit a job

Use the llsubmit command to submit a job to LoadLeveler to be dispatched
based upon job requirements in the job command file.


Syntax


llsubmit [-H] [-?] [-v] [-q] [-s] [-X {cluster_list | any}] [-p
user_monitor_program] [cmdfile | - ]


Flags


-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-q 
   Specifies quiet mode: print no messages other than error messages.

-s 
   Specifies that the llsubmit command will not exit until all steps of
   the job have completed. You cannot specify -s in combination with the
   -X flag.

-X {cluster_list | any}
   Is a blank-delimited list of cluster names or the reserved word any
   where: 

   *  A single cluster name indicates that the job is to be submitted to
      that cluster.

   *  A list of multiple cluster names indicates that the job is to be
      submitted to one of the clusters as determined by the installation
      exit CLUSTER_METRIC.

   *  The reserved word any indicates the job is to be submitted to any
      cluster defined by the installation exit CLUSTER_METRIC.    

   If a cluster_list is specified with the -X option on the llsubmit
   command, the specified cluster_list takes precedence over any
   cluster_list statements already specified in the job command file.    

   The -X multicluster option is not supported if the checkpoint keyword
   of the job is set to yes or interval. If specified, llsubmit returns
   an error message.

-p user_monitor_program
   Specifies a user-supplied program that will be invoked whenever the
   job state changes. The user-supplied program must be on a file system
   accessible to the Schedd daemon. The owner of the job must have
   execute permission for the program. The user monitor program receives
   the same information as the monitor_program user exit (for detailed
   information about the syntax and parameters, see the monitor_program
   user exit in LoadLeveler: Command and API Reference).

cmdfile
   Is the name of the job command file containing LoadLeveler commands.

-  Specifies that LoadLeveler commands that would normally be in the job
   command file are read from stdin. When entry is complete, press
   Ctrl-D to end the input.


Description


*  Users with uid or gid equal to 0 are not allowed to issue the
   llsubmit command.

*  When a LoadLeveler job ends, you may receive UNIX mail notification
   indicating the job exit status. For example, you could get the
   following mail message: 

   Your LoadLeveler job
   myjob1
   exited with status 139.    

   The return code 139 is from the user's job, and is not a LoadLeveler
   return code.

*  For information on writing a program to filter job scripts, see the
   "Filtering a job script" topic in LoadLeveler: Using and
   Administering.

*  The llsubmit command will display an error and fail to submit the job
   if the resources keyword in the job command file does not match the
   resources to be enforced and LoadLeveler is set to check for the
   resources specification. For more information, see the "Defining
   usage policies for consumable resources" topic in LoadLeveler: Using
   and Administering.

*  If the LL_RES_ID environment variable is set, the llsubmit command
   will set the requested reservation ID of the submitted job steps
   using the value of the LL_RES_ID environment variable. When the
   central manager receives the job steps from the Schedd, it will bind
   the job steps to a specified reservation. If the job steps cannot be
   bound to the reservation, they will be placed in the NotQueued state
   and the requested reservation ID will keep the same value. If the
   value of LL_RES_ID is set to blank, it will be treated as if it were
   unset. The value for the ll_res_id job command file keyword overrides
   the value for the LL_RES_ID environment variable.

*  If you want to submit a job to run on a specific type of machine (for
   example, one with Arch = i386 and OpSys= Linux2), you must specify a
   requirements statement that includes the Arch and OpSys requirements.

*  In a multicluster environment, job identifiers are assigned by the
   local cluster and are retained by the job regardless of what cluster
   the job runs in. 

   If the job was submitted as a remote job in a multicluster
   environment, the host represented in host.jobid.stepid, is the name
   of the local Schedd machine that assigned the jobid. To determine the
   managing Schedd machine, issue the llq -l command to obtain the
   Schedd Host field.    

   If the administrator has not defined a CLUSTER_METRIC for the local
   cluster, the llsubmit command will display an error and fail to
   submit the job if the user specifies the -X flag with a cluster_list
   or the reserved word any. The llsubmit command will also display an
   error and fail to submit the job if the user specifies the -X
   cluster_name in the following instances:
    
   *  The local cluster is not in the multicluster environment
   *  The specified cluster name is not configured
   *  The specified cluster name does not have inbound_hosts specified

*  Usage notes for submitting MetaCluster checkpoint jobs to
   LoadLeveler: 

   *  If the checkpoint (or restart_from_ckpt) keyword is set to yes and
      if the job_type keyword is not set to parallel, llsubmit returns
      an error message.

*  If the -S flag is specified with certain job command file statements,
   the job submission will fail and an error message will be displayed.
   For more information, see the cluster_option keyword in the job
   command file keyword descriptions topic in  LoadLeveler: Using and
   Administering.


Examples


1. This example shows a job command file named qtrlyrun.cmd is
   submitted: 

   llsubmit qtrlyrun.cmd    

   You should receive a response similar to the following when issued
   from the machine earth:    

   llsubmit: The job "earth.505" has been submitted.

2. This example shows a job being submitted to a remote cluster: 

   llsubmit -X cluster1 jcf.cmd     

   You should receive a response similar to the following:    

   Job c188f2n08.ppd.pok.ibm.com.21 assigned to local outbound 
                              Schedd c188f2n08.ppd.pok.ibm.com.
   Job c188f2n08.ppd.pok.ibm.com.21 assigned to remote inbound 
                              Schedd c188f2n02.ppd.pok.ibm.com.
   Job c188f2n08.ppd.pok.ibm.com.21 has been submitted to cluster "cluster1"
   llsubmit: The job "c188f2n08.ppd.pok.ibm.com.21" has been submitted.

3. This example shows a job command file specifying an inbound data
   staging step, an application job step, and an outbound data staging
   job step: 

   llsubmit 3step.cmd

   You should receive output similar to the following:
 
   llsubmit: The job "c197blade1b05.ppd.pok.ibm.com.11" with 3 job steps
   has been submitted.

4. The following example may result in an error when a submitted job
   requires a higher number of consumable resources for one of its steps
   than what is allowed in the corresponding class stanza: 

   llsubmit badconsres.cmd

   The following error messages are displayed: 

   llsubmit: 2512-058 The consumable resources requested exceed the
   maximum allowed for the class.
   
   llsubmit: 2512-051 This job has not been submitted to LoadLeveler.

5. This example shows how to bind the steps contained in jcf.cmd to
   occurrence 21 of the c197blade3b11.10.r recurring reservation: 

   LL_RES_ID=c197blade3b11.10.r.21 llsubmit jcf.cmd

   You should receive a response similar to the following: 

   llsubmit: The job "c197blade3b11.ppd.pok.ibm.com.77" has been submitted.

6. To submit job1.cmd and wait for the job's completion, issue: 

   llsubmit -s job1.cmd    

   The llsubmit command will not exit until all steps of the job have
   completed.

7. This example shows how to receive job state notification:

   llsubmit -p /commondir/my_monitor_program job1.cmd

   where my_monitor_program is the user monitor program that is on a
   shared file system where it can be accessed by the Schedd daemon.


Related Information


Subroutines: llsubmit