#!/bin/sh
# This script is used by the xCAT postscript process to configure the LoadLeveler 
# compute nodes when running LoadLeveler with the database option.  The 
# management server node should have already initialized the LoadLeveler database 
# using the llconfig -i command prior to executing this script.
#
# sccs id = @(#) src/ll/db/scripts/llcompute.sh, ll.db.gen, ll_rsnep2, rsnep21206a 1.3 12/2/11
#

POSTSCRIPT_PATH="LoadL"

# Clean up any existing copies of the generated files in the postscripts directory
/bin/rm -rf ${POSTSCRIPT_PATH}/LoadL.cfg.compute.generated

if [[ -z $MASTER ]]; then 
	echo "The MASTER environment variable is not set."
	echo "Verify that you are invoking this script under the xCAT postscript process."
	exit -1
fi

echo "replacing MASTER variable with the value defined in the environment..."
cat ${POSTSCRIPT_PATH}/LoadL.cfg.compute | sed "s/MASTER/${MASTER}/g" >> ${POSTSCRIPT_PATH}/LoadL.cfg.compute.tmp1

mv ${POSTSCRIPT_PATH}/LoadL.cfg.compute.tmp1 ${POSTSCRIPT_PATH}/LoadL.cfg.compute.generated

/bin/rm ${POSTSCRIPT_PATH}/LoadL.cfg.compute.tmp1

echo "Copying the LoadL.cfg file to /etc ... "
cp ${POSTSCRIPT_PATH}/LoadL.cfg.compute.generated /etc/LoadL.cfg
/bin/chmod 644 /etc/LoadL.cfg

USER=`cat /etc/LoadL.cfg 2>> /dev/null | grep -i loadluserid | sed 's/ //g' | cut -d'=' -f2`
if [[ -z $USER ]]; then
	USER="loadl"
fi
GROUP=`cat /etc/LoadL.cfg 2>> /dev/null | grep -i loadlgroupid | sed 's/ //g' | cut -d'=' -f2`
if [[ -z $GROUP ]]; then
	GROUP=`cat /etc/passwd 2>> /dev/null | grep "loadl:" | cut -d: -f4`
	if [[ -z $GROUP ]]; then
		echo "ERROR: Cannot determine the group for the loadl user.  Please verify that the user loadl has been created."
		exit -1
	fi
fi

# creating the log/spool/execute directories with the LoadLeveler
# user/group defined in LoadL.cfg, or defaulting to the loadl user id 
# and group found in /etc/passwd. The directories are created with 
# the following permissions:
#	log 	775
#	spool 	700 
# 	execute	1777

DIR_CONFIG_FILE="${POSTSCRIPT_PATH}/ll_config_directories"

while read line
do
	eval "/bin/mkdir -p $line"
	eval "/bin/chmod 777 $line"
	eval "/bin/chown -R ${USER}:${GROUP} $line"

	KW=${line##*/}
	if [[ ${KW} == "log" ]] ; then 
		eval "/bin/chmod 775 $line"
	elif [[ ${KW} == "spool" ]] ; then 
		eval "/bin/chmod 700 $line"
	elif [[ ${KW} == "execute" ]] ; then 
		eval "/bin/chmod 1777 $line"
	else 
		echo "error processing line: $line"
		exit -1
	fi
done < ${DIR_CONFIG_FILE}

