#
# ------------------------------------------------------------------------
# Sample Perl script to parse a reservation history file
# -------------------------------------------------------------------------
#
#char sccsid[] = "@(#) src/ll/samples/llres/llreshist.pl, ll.api, ll_rsnep2, rsnep21206a 1.8 11/18/11 18:35:29";

#
# Parse a LoadLeveler reservation history file and
# display the history information in a format similar
# that of llqres -l

$width = 20;
$buf = " " x ($width+2);

# Read each line from either stdin or from a list of files
while (<>) {
    ( $res_id,$res_type, $creation_time, $owner, $group,
      $req_start_time, $act_start_time,
      $req_duration, $act_duration,
      $end_time,$flex_job_id, 
      $shared, $rm_on_idle,
      $users, $groups, $notify_prog,$notify_prog_argu,
      $num_nodes, $nodes, $request_floating_res, 
      $num_bg_cnodes, $bg_connectivity, $bg_shape, $num_bg_mps, $bg_mps, $bg_block
    ) = split /!/ ;

	# Print a header containing the reservation id
    print "=" x 15, " Reservation ", $res_id, " ", "=" x 15, "\n";

	# Print each field from the history file on its own line
    printf "%${width}s: ", "Reservation Type";
    print $res_type, "\n";

    printf "%${width}s: ", "Creation Time";
    $tm_str = localtime($creation_time);
    print $tm_str, "\n";

    printf "%${width}s: ", "Owner";
    print $owner, "\n";

    printf "%${width}s: ", "Group";
    print $group, "\n";

    printf "%${width}s: ", "Requested Start Time";
    $tm_str = localtime($req_start_time);
    print $tm_str, "\n";

	# Actual Start Time == 0 is an indication the
	# reservation never became active (it was removed
	# while still in WAITING state).
    printf "%${width}s: ", "Actual Start Time";
    if ($act_start_time > 0) {
        $tm_str = localtime($act_start_time);
    } else {
        $tm_str = 0;
    }
    print $tm_str, "\n";

    printf "%${width}s: ", "Requested Duration";
    print $req_duration, " seconds (", duration_to_str($req_duration), ")\n";

    printf "%${width}s: ", "Actual Duration";
    print $act_duration, " seconds (", duration_to_str($act_duration), ")\n";

    printf "%${width}s: ", "Actual End Time";
    $tm_str = localtime($end_time);
    print $tm_str, "\n";

    printf "%${width}s: ", "Flexible Job Id";
    print $flex_job_id, "\n";

    printf "%${width}s: ", "Shared Mode";
    print $shared, "\n";

    printf "%${width}s: ", "Remove On Idle Mode";
    print $rm_on_idle, "\n";


	# For the user and group lists, print the number of
	# users/groups in the list, then print each user/group
	# on a separate line.

    printf "%${width}s: ", "Users";
    @user_list = split /,/, $users;
    print @user_list."\n";
    printf ( "$buf%s\n" x @user_list, @user_list);

    printf "%${width}s: ", "Groups";
    @group_list = split /,/, $groups;
    print @group_list."\n";
    printf ( "$buf%s\n" x @group_list, @group_list);

    printf "%${width}s: ", "Notify Program";
    print $notify_prog, "\n";

    printf "%${width}s: ", "Notify Program Argu";
    print $notify_prog_argu, "\n";
	
    printf "%${width}s: ", "Nodes";
    print $num_nodes, "\n";


	# Print each hostname on its own line.
	# The long_hostname subroutine will convert the short
	# name from the history file into the machine's full name.

    chomp $nodes;   # The \n is still there, so get rid of it
    @hostlist = long_hostname ( split ( /,/, $nodes ) );
    printf ( "$buf%s\n" x @hostlist, @hostlist);

    printf "%${width}s: ", "Floating Resources";
    @floating_res_list = split /,/, $request_floating_res;
    print @floating_res_list."\n";
    printf ( "$buf%s\n" x @floating_res_list, @floating_res_list);


	# Print BG reservation info

    next if ($num_bg_cnodes == 0);

    printf "%${width}s: ", "BG C-nodes";
    print $num_bg_cnodes, "\n";

    printf "%${width}s: ", "BG Connectivity";
    print $bg_connectivity, "\n";

    printf "%${width}s: ", "BG Shape";
    print $bg_shape, "\n";

    printf "%${width}s: ", "BG MPs";
    print $num_bg_mps, "\n";

	# Print each Midplane on its own line.
    chomp $bg_mps;   # The \n is still there, so get rid of it
    @mplist = split ( /,/, $bg_mps );
    printf ( "$buf%s\n" x @mplist, @mplist);

    printf "%${width}s: ", "BG Block";
    print $bg_block, "\n";

}

# long_hostname
#
# The reservation history file prints the short hostnames
# of the reserved machines.  For display purposes, get the
# full hostnames.
sub long_hostname {
    use Net::hostent;
    for $host (@_) {
    my $he = gethost($host);
        $host = $he->name;
    }
    @_;
}


# duration_to_str
#
# The reservation history file prints the requested duration
# and actual duration in seconds.  Convert that value here
# to a more user-friendly string.
sub duration_to_str {
    use integer;
    my $dur = $_[0];
    my $days = $dur / (24 * 60 * 60);
    my $hours =  ($dur / 3600) % 24;
    my $minutes = ($dur / 60) % 60;
    my $seconds = $dur % 60;
    my $str = sprintf("%d days %02d:%02d:%02d", $days, $hours, $minutes, $seconds);
}
