#!/bin/ksh

rm -f /tmp/job_notify.log /tmp/res_notify.log
rm -f *.err *.out

echo "================ This is a sample workflow engine =================="
echo "Please append LoadL_admin.part3 and LoadL_config.part3 to its corresponding LoadLeveler configuration file"
echo "Please make sure that LoadLeveler is started before executing this script."
echo ""

llq;llqres
echo "1. Create a flexible reservation with -f jcf and -p notify program to reserve nodes and floating resources"
res1=`llmkres -x -d 120 -f container_request.cmd -p res_notify.sh`
echo $res1
rid1=`echo ${res1} | cut -d" " -f4`
job1=`echo ${res1} | grep job  | awk -F\" '{print $2}' | sed 's/\"//g'`
echo container jobid = $job1
echo workflow reservation_id = $rid1

echo "2. Check for the reservation state to become RESERVATION_ACTIVE from the notification program"
timeout=30
sleep 5
while((timeout))
do
  cnt=`grep "RESERVATION_ACTIVE" /tmp/res_notify.log| grep $rid1`
  if [ -z $cnt ];then
      echo "Haven't got reservation Active message yet"
      sleep 3
      ((timeout-=1))
  else
      echo "Got reservation Active message! Go on.."
      break
  fi
done
echo "$timeout"
if [ $timeout -eq 0 ];then
  echo "Haven't got reservation Active message before timeout"
  exit 1
fi

llq
llqres
echo "3. submit some jobs and bind some of them to reservation"
job1=`LL_RES_ID=$rid1 llsubmit job1.cmd.wf -p job_notify.sh| cut -d"\"" -f2`
job2=`LL_RES_ID=$rid1 llsubmit job2.cmd.wf -p job_notify.sh| cut -d"\"" -f2`
echo $job1 $job2 
llq -l $job1 $job2|grep "Reservation ID"

echo "4. Check when all jobs inside the reservation are finished, then remove the reservation"
timeout=30
sleep 5
while((timeout))
do
  cnt1=`grep "JOB_COMPLETE" /tmp/job_notify.log| grep $job1`
  cnt2=`grep "JOB_COMPLETE" /tmp/job_notify.log| grep $job2`
  if [[ (-z $cnt1) || (-z $cnt2) ]];then
      echo "Jobs haven't complete inside workflow.."
      sleep 5
      ((timeout-=1))
  else
      echo "ALL jobs inside workflow are completed!"
      break
  fi
done
echo "$timeout"
if [ $timeout -eq 0 ];then
  echo "Not all jobs inside workflow are completed before timeout"
  exit 2
fi

llrmres -R $rid1

echo "5. Check for the reservation state to become RESERVATION_REMOVED from the notification program"
timeout=30
sleep 5
while((timeout))
do
  cnt=`grep "RESERVATION_REMOVED" /tmp/res_notify.log|grep $rid1`
  if [ -z $cnt ];then
      echo "Haven't got reservation Removed message yet"
      sleep 3
      ((timeout-=1))
  else
      echo "Got reservation Removed message! Go on.."
      break
  fi
done
echo "$timeout"
if [ $timeout -eq 0 ];then
  echo "Haven't got reservation Removed message before timeout"
  exit 4
fi

llq;llqres

exit 0
